.. sidebar:: Key contributors
   :subtitle: `scVI graph`_ | # = maintainer, ☀ = diverse contributions

   * `Romain Lopez`_: scVI lead, ☀, #
   * `Adam Gayoso`_: totalVI lead, LDVAE, ☀, #
   * Pierre Boyeau: differential expression, ☀, #
   * `Galen Xing`_: code infrastructure, ☀, #
   * `Jeffrey Regier`_: initial scVI package, ☀
   * Chenling Xu : scANVI, ☀
   * `Valentine Svensson`_: LDVAE, ☀
   * Oscar Clivio : AutoZI, ☀
   * `Achille Nazaret`_ : gimVI, GeneExpressionDataset, ☀
   * Gabriel Misrachi : autotune, GeneExpressionDataset, ☀
   * Yining Liu : data loading, preprocessing, ☀
   * Jules Samaran : gimVI, ☀
   * Maxime Langevin : gimVI, ☀
   * Edouard Mehlman : code infrastructure, scANVI, ☀


.. _scVI graph: https://github.com/YosefLab/scVI/graphs/contributors
.. _Romain Lopez: https://romain-lopez.github.io/
.. _Adam Gayoso: https://adamgayoso.com/
.. _Jeffrey Regier: https://regier.stat.lsa.umich.edu/
.. _Valentine Svensson: http://www.nxn.se/
.. _Achille Nazaret: https://nazaret.me/
.. _Galen Xing: https://galenxing.com/
